@@ -1,62 +1,61 @@
-#' Plot an integrated profile (\code{vpi})
+#' Plot an integrated profile (`vpi`)
 #'
-#' Plot an object of class \code{vpi}.
+#' Plot an object of class `vpi`.
 #'
-#' @param x 1 class object inheriting from class \code{vpi}, typically a
-#' call to \link[bioRad]{integrate_profile}.
+#' @param x 1 class object inheriting from class `vpi`, typically a
+#' call to [integrate_profile][bioRad::integrate_profile].
 #' @param quantity Character string with the quantity to plot, one of
-#' '\code{vid}' (vertically integrated density),
-#' '\code{vir}' (vertically integrated reflectivity),
-#' '\code{mtr}' (migration traffic rate),
-#' '\code{rtr}' (reflectivity traffic rate),
-#' '\code{mt}' ((cumulative) migration traffic),
-#' '\code{rt}' ((cumulative) reflectivity traffic),
-#' '\code{ff}' (height-averaged ground speed)
-#' '\code{dd}' (height-averaged direction)
-#' '\code{u}' (height-averaged u-component of ground speed),
-#' '\code{v}' (height-averaged v-component of ground speed).
+#' * `vid` (vertically integrated density),
+#' * `vir` (vertically integrated reflectivity),
+#' * `mtr` (migration traffic rate),
+#' * `rtr` (reflectivity traffic rate),
+#' * `mt` ((cumulative) migration traffic),
+#' * `rt` ((cumulative) reflectivity traffic),
+#' * `ff` (height-averaged ground speed)
+#' * `dd` (height-averaged direction)
+#' * `u` (height-averaged u-component of ground speed),
+#' * `v` (height-averaged v-component of ground speed).
 #' @param ylim y-axis plot range, numeric atomic vector of length 2.
 #' @param xlab A title for the x-axis.
 #' @param ylab A title for the y-axis.
 #' @param main A title for the plot.
 #' @param night_shade Logical, whether to plot night time shading.
 #' @param elev Numeric, sun elevation to use for day/night transition,
-#' see \link{sunrise}.
+#' see [sunrise].
 #' @param lat (optional) Latitude in decimal degrees. Overrides the lat
-#' attribute of \code{x}.
+#' attribute of `x`.
 #' @param lon (optional) Longitude in decimal degrees. Overrides the lon
-#' attribute of \code{x}.
+#' attribute of `x`.
 #' @param ... Additional arguments to be passed to the low level
-#' \link[graphics]{plot} plotting function.
+#' [plot][graphics::plot] plotting function.
 #' @param nightshade Deprecated argument, use night_shade instead.
-#'
+#' @returns No return value, side effect is a plot.
 #' @method plot vpi
 #'
 #' @export
 #'
 #' @details
 #' The integrated profiles can be visualized in various related quantities, as specified by
-#' argument \code{quantity}:
-#' \describe{
-#'  \item{"\code{vid}"}{Vertically Integrated Density, i.e. the aerial surface
-#'    density of individuals. This quantity is dependent on the assumed radar
-#'    cross section per individual (RCS)}
-#'  \item{"\code{vir}"}{Vertically Integrated Reflectivity. This quantity is
-#'    independent of the value of individual's radar cross section}
-#'  \item{"\code{mtr}"}{Migration Traffic Rate. This quantity is dependent on
-#'    the assumed radar cross section (RCS)}
-#'  \item{"\code{rtr}"}{Reflectivity Traffic Rate. This quantity is independent
-#'    on the assumed radar cross section (RCS)}
-#'  \item{"\code{mt}"}{Migration Traffic. This quantity is dependent on
-#'    the assumed radar cross section (RCS)}
-#'  \item{"\code{rt}"}{Reflectivity Traffic. This quantity is independent
-#'    on the assumed radar cross section (RCS)}
-#'  \item{\code{ff}}{Horizontal ground speed in m/s}
-#'  \item{\code{dd}}{Horizontal ground speed direction in degrees}
-#'  \item{\code{u}}{Ground speed component west to east in m/s}
-#'  \item{\code{v}}{Ground speed component south to north in m/s}
-#'  \item{\code{height}}{Mean flight height (height weighted by reflectivity eta) in m above sea level}
-#' }
+#' argument `quantity`:
+#' * `vid`: Vertically Integrated Density, i.e. the aerial surface density of
+#'   individuals. This quantity is dependent on the assumed radar cross section
+#'   per individual (RCS)
+#' * `vir`: Vertically Integrated Reflectivity. This quantity is independent of
+#'   the value of individual's radar cross section
+#' * `mtr`: Migration Traffic Rate. This quantity is dependent on the assumed
+#'   radar cross section (RCS)
+#' * `rtr`: Reflectivity Traffic Rate. This quantity is independent on the
+#'   assumed radar cross section (RCS)
+#' * `mt`: Migration Traffic. This quantity is dependent on the assumed radar
+#'   cross section (RCS)
+#' * `rt`: Reflectivity Traffic. This quantity is independent on the assumed
+#'   radar cross section (RCS)
+#' * `ff`: Horizontal ground speed in m/s
+#' * `dd`: Horizontal ground speed direction in degrees
+#' * `u`: Ground speed component west to east in m/s
+#' * `v`: Ground speed component south to north in m/s
+#' * `height`: Mean flight height (height weighted by reflectivity eta) in m
+#'   above sea level
 #' The height-averaged ground speed quantities (ff,dd,u,v) and height are weighted averages by reflectivity eta.
 #' @examples
 #' # vertically integrate a vpts object:
@@ -70,12 +69,12 @@ plot.vpi <- function(x, quantity = "mtr", xlab = "time",
                      main = "MTR", night_shade = TRUE,
                      elev = -0.268, lat = NULL, lon = NULL, ylim = NULL, nightshade = TRUE, ...) {
   stopifnot(inherits(x, "vpi"))
-  assert_that(
+  assertthat::assert_that(
     quantity %in% names(x) & quantity != "datetime",
-    msg = glue("quantity `{quantity}` not found in vpi object.")
+    msg = glue::glue("quantity `{quantity}` not found in vpi object.")
   )
 
-  if (hasArg("param")) stop("unknown function argument 'param`. Did you mean `quantity`?")
+  if (methods::hasArg("param")) stop("unknown function argument 'param`. Did you mean `quantity`?")
 
   # deprecate function argument
   if (!missing(nightshade)) {
@@ -124,7 +123,7 @@ plot.vpi <- function(x, quantity = "mtr", xlab = "time",
   if (night_shade) {
     if (!is.numeric(lat) || !is.numeric(lon)) {
       stop(
-        "No latitude/longitude found in attribute data, please provide",
+        "No latitude/longitude found in attribute data, please provide ",
         "lat and lon arguments when night_shade=TRUE."
       )
     }
@@ -159,14 +158,14 @@ plot.vpi <- function(x, quantity = "mtr", xlab = "time",
 
     # plot night time shading for each night.
     for (i in 1:length(days)) {
-      polygon(c(tset[i], trise[i], trise[i], tset[i]),
+      graphics::polygon(c(tset[i], trise[i], trise[i], tset[i]),
         ypolygon,
         lty = 0, col = "#CCCCCC"
       )
     }
 
     # plot the data again on top of the shading
-    points(x$datetime, x[quantity][[1]],
+    graphics::points(x$datetime, x[quantity][[1]],
       type = "l",
       xlab = "time", ylab = ylab, ylim = ylim, main = main, ...
     )
