@@ -4,12 +4,12 @@
 #'
 #' @inheritParams beam_height
 #' @param scan a scan (sweep) of class scan
-#' @param lat Geodetic latitude of the radar in degrees. If missing taken from \code{scan}.
-#' @param lon Geodetic longitude of the radar in degrees. If missing taken from \code{scan}.
+#' @param lat Geodetic latitude of the radar in degrees. If missing taken from `scan`.
+#' @param lon Geodetic longitude of the radar in degrees. If missing taken from `scan`.
 #' @return a SpatialPointsDataFrame
 #' @export
-#' @details Beam altitude accounts for the curvature of the earth, using \link{beam_height}.
-#' Distance from the radar over the earth's surface is calculated using \link{beam_distance}.
+#' @details Beam altitude accounts for the curvature of the earth, using [beam_height].
+#' Distance from the radar over the earth's surface is calculated using [beam_distance].
 #' @examples
 #' # load example scan:
 #' data(example_scan)
@@ -17,18 +17,18 @@
 #' # convert to a SpatialPointsDataFrame:
 #' scan_to_spatial(example_scan)
 scan_to_spatial <- function(scan, lat, lon, k = 4 / 3, re = 6378, rp = 6357) {
-  assert_that(is.scan(scan))
-  assert_that(is.number(k))
-  assert_that(is.number(re))
-  assert_that(is.number(rp))
+  assertthat::assert_that(is.scan(scan))
+  assertthat::assert_that(assertthat::is.number(k))
+  assertthat::assert_that(assertthat::is.number(re))
+  assertthat::assert_that(assertthat::is.number(rp))
   if (is.null(scan$geo$lat) && missing(lat)) stop("radar latitude cannot be found in scan, specify using 'lat' argument")
   if (is.null(scan$geo$lon) && missing(lon)) stop("radar longitude cannot be found in scan, specify using 'lon' argument")
   if (missing(lat)) lat <- scan$geo$lat
   if (missing(lon)) lon <- scan$geo$lon
-  assert_that(is.number(lat))
-  assert_that(is.number(lon))
+  assertthat::assert_that(assertthat::is.number(lat))
+  assertthat::assert_that(assertthat::is.number(lon))
 
-  proj4string <- CRS(paste("+proj=aeqd +lat_0=", lat,
+  proj4string <- sp::CRS(paste("+proj=aeqd +lat_0=", lat,
     " +lon_0=", lon,
     " +units=m",
     sep = ""
@@ -52,7 +52,7 @@ scan_to_spatial <- function(scan, lat, lon, k = 4 / 3, re = 6378, rp = 6357) {
     x = data$distance * cos(pi / 2 - data$azim * pi / 180),
     y = data$distance * sin(pi / 2 - data$azim * pi / 180)
   )
-  SpatialPointsDataFrame(coords = coords, data = data, coords.nrs = c(3, 4), proj4string = proj4string)
+  sp::SpatialPointsDataFrame(coords = coords, data = data, coords.nrs = c(3, 4), proj4string = proj4string)
 }
 
 #' convert a polar scan into a raster
@@ -63,20 +63,21 @@ scan_to_spatial <- function(scan, lat, lon, k = 4 / 3, re = 6378, rp = 6357) {
 #' @param ny number of raster pixels in the y (latitude) dimension
 #' @param xlim x (longitude) range
 #' @param ylim y (latitude) range
-#' @param param scan parameters to include. If \code{NA} include all scan parameters. Reducing the number
+#' @param param scan parameters to include. If `NA` include all scan parameters. Reducing the number
 #' of scan parameters speeds up evaluation.
 #' @param crs character or object of class CRS. PROJ.4 type description of a Coordinate Reference System (map projection).
 #' When 'NA' (default), an azimuthal equidistant projection with origin at the radar location is used.
 #' To use a WSG84 (lat,lon) projection, use crs="+proj=longlat +datum=WGS84"
-#' @param res numeric vector of length 1 or 2 to set the resolution of the raster (see \link[raster]{res}).
-#' If this argument is used, arguments \code{nx} and \code{ny} are ignored. Unit is identical to \code{xlim} and \code{ylim}.
+#' @param res numeric vector of length 1 or 2 to set the resolution of the raster (see [res][raster::res]).
+#' If this argument is used, arguments `nx` and `ny` are ignored. Unit is identical to `xlim` and `ylim`.
 #' @param raster (optional) RasterLayer with a CRS. When specified this raster topology is used for the output, and nx, ny, res
 #' arguments are ignored.
 #' @return a RasterBrick
-#' @details uses \link{scan_to_spatial} to georeference the scan's pixels. If multiple scan pixels fall within
-#' the same raster pixel, the last added pixel is given (see \link[raster]{rasterize} for details).
+#' @details uses [scan_to_spatial] to georeference the scan's pixels. If multiple scan pixels fall within
+#' the same raster pixel, the last added pixel is given (see [rasterize][raster::rasterize] for details).
 #' @export
 #' @examples
+#' \donttest{
 #' # default projects full extent on 100x100 pixel raster:
 #' scan_to_raster(example_scan)
 #'
@@ -86,11 +87,12 @@ scan_to_spatial <- function(scan, lat, lon, k = 4 / 3, re = 6378, rp = 6357) {
 #' # using a template raster
 #' template_raster <- raster::raster(raster::extent(12, 13, 56, 58), crs = sp::CRS("+proj=longlat"))
 #' scan_to_raster(example_scan, raster = template_raster)
+#' }
 scan_to_raster <- function(scan, nx = 100, ny = 100, xlim, ylim, res = NA, param, raster = NA, lat, lon, crs = NA, k = 4 / 3, re = 6378, rp = 6357) {
   if (!is.scan(scan)) stop("'scan' should be an object of class scan")
   if (get_elevation_angles(scan) == 90) stop("georeferencing of 90 degree birdbath scan not supported")
-  if (!is.number(nx) && missing(res)) stop("'nx' should be an integer")
-  if (!is.number(ny) && missing(res)) stop("'ny' should be an integer")
+  if (!assertthat::is.number(nx) && missing(res)) stop("'nx' should be an integer")
+  if (!assertthat::is.number(ny) && missing(res)) stop("'ny' should be an integer")
   if (!missing(xlim)) {
     if (length(xlim) != 2 & !is.numeric(xlim)) stop("'xlim' should be an integer vector of length two")
     if (is.na(xlim[1]) | is.na(xlim[2]) | xlim[1] > xlim[2]) stop("'xlim' should be a vector with two numeric values for upper and lower bound")
@@ -100,8 +102,8 @@ scan_to_raster <- function(scan, nx = 100, ny = 100, xlim, ylim, res = NA, param
     if (is.na(ylim[1]) | is.na(ylim[2]) | ylim[1] > ylim[2]) stop("'ylim' should be a vector with two numeric values for upper and lower bound")
   }
   if (!missing(res) && !is.na(res)) {
-    assert_that(is.numeric(res))
-    assert_that(length(res) <= 2)
+    assertthat::assert_that(is.numeric(res))
+    assertthat::assert_that(length(res) <= 2)
   }
   if (!missing(param)) {
     if (FALSE %in% (param %in% c(names(scan$params), "azim", "range", "distance"))) stop("'param' contains scan parameter not found in scan")
@@ -112,8 +114,8 @@ scan_to_raster <- function(scan, nx = 100, ny = 100, xlim, ylim, res = NA, param
   else {
     param_to_use <- names(scan$params)
   }
-  if (!are_equal(raster, NA)) {
-    assert_that(inherits(raster, "RasterLayer"))
+  if (!assertthat::are_equal(raster, NA)) {
+    assertthat::assert_that(inherits(raster, "RasterLayer"))
   }
 
   if (is.null(scan$geo$lat) && missing(lat)) stop("radar latitude cannot be found in scan, specify using 'lat' argument")
@@ -122,9 +124,9 @@ scan_to_raster <- function(scan, nx = 100, ny = 100, xlim, ylim, res = NA, param
   if (missing(lat)) lat <- scan$geo$lat
   if (missing(lon)) lon <- scan$geo$lon
 
-  assert_that(is.number(lat))
-  assert_that(is.number(lon))
-  localCrs <- CRS(paste("+proj=aeqd +lat_0=", lat,
+  assertthat::assert_that(assertthat::is.number(lat))
+  assertthat::assert_that(assertthat::is.number(lon))
+  localCrs <- sp::CRS(paste("+proj=aeqd +lat_0=", lat,
     " +lon_0=", lon,
     " +units=m",
     sep = ""
@@ -134,14 +136,14 @@ scan_to_raster <- function(scan, nx = 100, ny = 100, xlim, ylim, res = NA, param
   }
   else {
     # check crs argument as in raster::raster()
-    crs <- CRS(as.character(raster::projection(crs)))
+    crs <- sp::CRS(as.character(raster::projection(crs)))
   }
-  if (!are_equal(raster, NA)) {
+  if (!assertthat::are_equal(raster, NA)) {
     crs <- raster::crs(raster)
   }
-  assert_that(is.number(k))
-  assert_that(is.number(re))
-  assert_that(is.number(rp))
+  assertthat::assert_that(assertthat::is.number(k))
+  assertthat::assert_that(assertthat::is.number(re))
+  assertthat::assert_that(assertthat::is.number(rp))
 
   rscale <- scan$geo$rscale
   ascale <- scan$geo$ascale
@@ -159,25 +161,25 @@ scan_to_raster <- function(scan, nx = 100, ny = 100, xlim, ylim, res = NA, param
     # keep only selected scan parameters
     if (!missing(param)) spdf <- spdf[param]
     # transform spatialpoints to coordinate system of the raster
-    if (!missing(crs)) spdf <- spTransform(spdf, crs)
+    if (!missing(crs)) spdf <- sp::spTransform(spdf, crs)
     # get extent of the available data
     spdf_extent <- raster::extent(spdf)
     # prepare a raster matching the data extent (or user-specified extent)
     if (missing(xlim)) xlim <- c(spdf_extent@xmin, spdf_extent@xmax)
     if (missing(ylim)) ylim <- c(spdf_extent@ymin, spdf_extent@ymax)
   }
-  if (!are_equal(raster, NA)) {
-    r <- raster(raster)
+  if (!assertthat::are_equal(raster, NA)) {
+    r <- raster::raster(raster)
   } else {
     if (missing(res) | is.na(res)) {
-      r <- raster(ncols = nx, nrows = ny, ext = raster::extent(c(xlim, ylim)), crs = crs)
+      r <- raster::raster(ncols = nx, nrows = ny, ext = raster::extent(c(xlim, ylim)), crs = crs)
     }
     else {
-      r <- raster(ncols = nx, nrows = ny, ext = raster::extent(c(xlim, ylim)), crs = crs, res = res)
+      r <- raster::raster(ncols = nx, nrows = ny, ext = raster::extent(c(xlim, ylim)), crs = crs, res = res)
     }
   }
   # convert raster coordinates to local Cartesian CRS
-  crds <- coordinates(spTransform(rasterToPoints(r, spatial = T), localCrs))
+  crds <- sp::coordinates(sp::spTransform(raster::rasterToPoints(r, spatial = TRUE), localCrs))
   # convert raster coordinates to polar indices
   polar_coords <- cartesian_to_polar(crds, elev = scan$geo$elangle, k = k, lat = lat, re = re, rp = rp)
   index <- polar_to_index(polar_coords, rangebin = rscale, azimbin = ascale, rangestart = rstart, azimstart = astart)
@@ -233,17 +235,17 @@ scan_to_spdf <- function(scan, spdf, param, lat, lon, k = 4 / 3, re = 6378, rp =
   if (missing(lat)) lat <- scan$geo$lat
   if (missing(lon)) lon <- scan$geo$lon
 
-  assert_that(is.number(lat))
-  assert_that(is.number(lon))
-  localCrs <- CRS(paste("+proj=aeqd +lat_0=", lat,
+  assertthat::assert_that(assertthat::is.number(lat))
+  assertthat::assert_that(assertthat::is.number(lon))
+  localCrs <- sp::CRS(paste("+proj=aeqd +lat_0=", lat,
     " +lon_0=", lon,
     " +units=m",
     sep = ""
   ))
-  assert_that(is.number(k))
-  assert_that(is.number(re))
-  assert_that(is.number(rp))
-  stopifnot(all.equal(localCrs, CRS(proj4string(spdf))))
+  assertthat::assert_that(assertthat::is.number(k))
+  assertthat::assert_that(assertthat::is.number(re))
+  assertthat::assert_that(assertthat::is.number(rp))
+  stopifnot(all.equal(localCrs, sp::CRS(sp::proj4string(spdf))))
 
   rscale <- scan$geo$rscale
   ascale <- scan$geo$ascale
@@ -253,7 +255,7 @@ scan_to_spdf <- function(scan, spdf, param, lat, lon, k = 4 / 3, re = 6378, rp =
   nrang <- dim(scan)[2]
   nazim <- dim(scan)[3]
 
-  crds <- coordinates(spdf)
+  crds <- sp::coordinates(spdf)
   # convert raster coordinates to polar indices
   polar_coords <- cartesian_to_polar(crds, elev = scan$geo$elangle, k = k, lat = lat, re = re, rp = rp)
   index <- polar_to_index(polar_coords, rangebin = rscale, azimbin = ascale, rangestart = rstart, azimstart = astart)
